@@ -1,3 +1,5 @@
+#include <sys/types.h>
+
 #include <err.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,7 +41,8 @@ printfeed(FILE *fp, struct feed *f)
 			break;
 
 		parsedtime = 0;
-		strtotime(fields[FieldUnixTimestamp], &parsedtime);
+		if (strtotime(fields[FieldUnixTimestamp], &parsedtime))
+			continue;
 	        if (!(tm = localtime(&parsedtime)))
 			err(1, "localtime");
 
