@@ -1,3 +1,5 @@
+#include <sys/types.h>
+
 #include <ctype.h>
 #include <err.h>
 #include <locale.h>
@@ -27,7 +29,8 @@ printfeed(FILE *fp, const char *feedname)
 			break;
 
 		parsedtime = 0;
-		strtotime(fields[FieldUnixTimestamp], &parsedtime);
+		if (strtotime(fields[FieldUnixTimestamp], &parsedtime))
+			continue;
 	        if (!(tm = localtime(&parsedtime)))
 			err(1, "localtime");
 
@@ -36,8 +39,10 @@ printfeed(FILE *fp, const char *feedname)
 		else
 			fputs("  ", stdout);
 
-		if (feedname[0])
-			printf("%-15.15s  ", feedname);
+		if (feedname[0]) {
+			printutf8pad(stdout, feedname, 15, ' ');
+			fputs("  ", stdout);
+		}
 
 	        fprintf(stdout, "%04d-%02d-%02d %02d:%02d  ",
 		        tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
