@@ -1,3 +1,5 @@
+#include <sys/types.h>
+
 #include <ctype.h>
 #include <err.h>
 #include <stdint.h>
@@ -46,6 +48,8 @@ xmltagstartparsed(XMLParser *p, const char *tag, size_t taglen, int isshort)
 
 	if (absuri(abslink, sizeof(abslink), feedlink, basehref) != -1)
 		fputs(abslink, stdout);
+	else
+		fputs(feedlink, stdout);
 	fputc('\t', stdout);
 	printfeedtype(feedtype, stdout);
 	putchar('\n');
