@@ -35,7 +35,7 @@ parseuri(const char *s, struct uri *u, int rel)
 			       *p == '+' || *p == '-' || *p == '.'); p++)
 			;
 		if (!strncmp(p, "://", 3)) {
-			if (p - s >= (ssize_t)sizeof(u->proto))
+			if ((size_t)(p - s) >= sizeof(u->proto))
 				return -1; /* protocol too long */
 			memcpy(u->proto, s, p - s);
 			u->proto[p - s] = '\0';
@@ -50,10 +50,10 @@ parseuri(const char *s, struct uri *u, int rel)
 	/* IPv6 address */
 	if (*p == '[') {
 		/* bracket not found or host too long */
-		if (!(b = strchr(p, ']')) || b - p >= (ssize_t)sizeof(u->host))
+		if (!(b = strchr(p, ']')) || (size_t)(b - p) >= (ssize_t)sizeof(u->host))
 			return -1;
 		memcpy(u->host, p + 1, b - p - 1);
-		u->host[b - p] = '\0';
+		u->host[b - p - 1] = '\0';
 		p = b + 1;
 	} else {
 		/* domain / host part, skip until port, path or end. */
@@ -267,55 +267,3 @@ printutf8pad(FILE *fp, const char *s, size_t len, int pad)
 	for (; col < len; col++)
 		putc(pad, fp);
 }
-
-uint32_t
-murmur3_32(const char *key, uint32_t len, uint32_t seed)
-{
-	static const uint32_t c1 = 0xcc9e2d51;
-	static const uint32_t c2 = 0x1b873593;
-	static const uint32_t r1 = 15;
-	static const uint32_t r2 = 13;
-	static const uint32_t m = 5;
-	static const uint32_t n = 0xe6546b64;
-	uint32_t hash = seed;
-	const int nblocks = len / 4;
-	const uint32_t *blocks = (const uint32_t *) key;
-	int i;
-	uint32_t k, k1;
-	const uint8_t *tail;
-
-	for (i = 0; i < nblocks; i++) {
-		k = blocks[i];
-		k *= c1;
-		k = ROT32(k, r1);
-		k *= c2;
-
-		hash ^= k;
-		hash = ROT32(hash, r2) * m + n;
-	}
-	tail = (const uint8_t *) (key + nblocks * 4);
-
-	k1 = 0;
-	switch (len & 3) {
-	case 3:
-		k1 ^= tail[2] << 16;
-	case 2:
-		k1 ^= tail[1] << 8;
-	case 1:
-		k1 ^= tail[0];
-
-		k1 *= c1;
-		k1 = ROT32(k1, r1);
-		k1 *= c2;
-		hash ^= k1;
-	}
-
-	hash ^= len;
-	hash ^= (hash >> 16);
-	hash *= 0x85ebca6b;
-	hash ^= (hash >> 13);
-	hash *= 0xc2b2ae35;
-	hash ^= (hash >> 16);
-
-	return hash;
-}
